summaryrefslogtreecommitdiffstats
path: root/kdeui/kurllabel.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit1dcbbe821d337f155c5835aa372db3cadcc31ed8 (patch)
treea0b305d9d9334acfe296542840e8e05fbc63bae9 /kdeui/kurllabel.cpp
parent9c49a74a165b8535c28ccbb2fad37334989b2fc7 (diff)
downloadtdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.tar.gz
tdelibs-1dcbbe821d337f155c5835aa372db3cadcc31ed8.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kurllabel.cpp')
-rw-r--r--kdeui/kurllabel.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdeui/kurllabel.cpp b/kdeui/kurllabel.cpp
index 884ff6a59..9846059ed 100644
--- a/kdeui/kurllabel.cpp
+++ b/kdeui/kurllabel.cpp
@@ -353,8 +353,8 @@ bool KURLLabel::event (TQEvent *e)
{
if (e && e->type() == TQEvent::ParentPaletteChange)
{
- // use tqparentWidget() unless you are a toplevel widget, then try qAapp
- TQPalette p = tqparentWidget() ? tqparentWidget()->palette() : tqApp->palette();
+ // use parentWidget() unless you are a toplevel widget, then try qAapp
+ TQPalette p = parentWidget() ? parentWidget()->palette() : tqApp->palette();
p.setBrush(TQColorGroup::Base, p.brush(TQPalette::Normal, TQColorGroup::Background));
p.setColor(TQColorGroup::Foreground, tqpalette().active().foreground());
setPalette(p);